Learn R Programming

solaR (version 0.23)

B3_G0-class: Class "G0": irradiation and irradiance on the horizontal plane.

Description

This class contains the global, diffuse and direct irradiation and irradiance on the horizontal plane, and ambient temperature.

Arguments

encoding

UTF-8

Objects from the Class

Objects can be created by the function calcG0.

Extends

Class "Meteo", directly. Class "Sol", directly.

References

Perpiñán, O, Energía Solar Fotovoltaica, 2011. (http://procomun.wordpress.com/documentos/libroesf/)

See Also

Sol, Gef.