Learn R Programming

solaR (version 0.23)

B4_Gef-class: Class "Gef": irradiation and irradiance on the generator plane.

Description

This class contains the global, diffuse and direct irradiation and irradiance on the horizontal plane, and ambient temperature.

Arguments

encoding

UTF-8

Objects from the Class

Objects can be created by the function calcGef.

Extends

Class "G0", directly. Class "Meteo", by class "G0", distance 2. Class "Sol", by class "G0", distance 2.

References

Perpiñán, O, Energía Solar Fotovoltaica, 2011. (http://procomun.wordpress.com/documentos/libroesf/)

See Also

Sol, G0.