fSolI or calcSoland from the information supplied by the
arguments beta and alfa when the surface is fixed
(modeTrk='fixed') or the movement equations when a tracking
surface is chosen (modeTrk='horiz' or modeTrk='two').
Besides, the modified movement of a horizontal NS tracker due to the
backtracking strategy is calculated if BT=TRUE with information
about the tracker and the distance between the trackers included in the
system. This function is used by the calcGef function.
fTheta(sol, beta, alfa = 0, modeTrk = "fixed", betaLim = 90,
BT = FALSE, struct, dist)Sol object as provided by calcSol.modeTrk='fixed'.modeTrk='fixed'. Its default value is alfa=0'fixed', 'two' or 'horiz'. When modeTrk='fixed' the surface is fixed (inclination and azimuth angles are constant). The performance of a two-axis tracker is calculated with <TRUE when the bactracking technique is to be used with a horizontal NS tracker, as described by Panico et al. (see References). The default value is FALSE. In future versions of this package this technique will be availaBT=TRUE. A list, with a component named L, which is the height (meters) of the tracker. In future versions the backtracking technique will be used in conjuction with two-axis trackers, and a additionBT=TRUE. A data.frame, with a component named Lew, being the distance between the horizontal NS trackers along the East-West direction. In future versions an additional component named Lnszoo object with these components:modeTrk='fixed' it is the value of the argument beta converted from degrees to radians.modeTrk='fixed' it is the value of the argument alfa converted from degrees to radians.fInclin,
fSombra,
calcGef.