NmgSFB(Bomba, Pg, H, Gd, Ta=30,lambda=0.0045, TONC=47, eta=0.95,
Gmax=1200,t0=6,Nm=6)list, with Qn, the rated flow of the pump, and Etapas, the number of stageslist with the results of irradiance, power and flow of the systemlist with the results of total irradiation, electrical energy and flow for every nominal power of the generatorlist with the arguments used in the call to the functiontrellis object containing the nomogramCoefBomba.fBomba, prodSFB, CoefBombaPg=seq(3000,5500,by=500)
H=seq(50,80,by=5)
Bomba=list(Qn=8,Etapas=44)
NmgSFB(Bomba=Bomba,Pg=Pg,H=H,Gd=6000)Run the code above in your browser using DataLab