prodSFCR, prodSFB and optimSombra. Its result is included as the D component of the lists provided by these functions.resumenProdSFCR(Prod)
resumenProdSFB(Prod)list containing the result of fProd and a list containing several parameters as modoRad, DiasMes and Pglist with three components containing values of AC energy (Eac), global effective irradiation (Gef), global irradiation on the horizontal plane (G0) and final productivity of the system (Yf). For grid connected PV systems the performance ratio of the system (PR) is included but for PV pumping systems the flow normalized to the nominal PV power is provided, Qn.data.frame, daily values. When (Prod$para$modoRad='prom') this component is NULLdata.frame, monthly valuesdata.frame, yearly valuesprodSFCR,
prodSFB,
optimSombra,
aggregate