Learn R Programming

solaR (version 0.41)

solaR-defunct: Defunct functions in package solaR

Description

These functions are defunct and no longer available.

Arguments

encoding

UTF-8

Details

readSIAR: The SIAR webpage cannot be accessed with a direct URL but using javascript code. Therefore, the function readSIAR no longer works. This help page is still here as a reference. The SIAR webpage is now http://eportal.magrama.gob.es/websiar.