Learn R Programming

solaR (version 0.41)

solaR-deprecated: Deprecated functions in package solaR

Description

These functions are provided for compatibility with older versions of solaR only, and will be defunct at the next release.

Arguments

encoding

UTF-8

Details

The following functions are deprecated and will be made defunct; use the replacement indicated below:
  • TargetDiagram, analyzeData: Use thetdrpackage